@@ -11,14 +11,24 @@
 #   under the License.
 
 import copy
-import mock
 
+import mock
 from osc_lib.tests import utils as osc_lib_utils
 
 from openstackclient import shell
 from openstackclient.tests.unit.integ import base as test_base
 from openstackclient.tests.unit import test_shell
 
+# NOTE(dtroyer): Attempt the import to detect if the SDK installed is new
+#                enough to contain the os_client_config code.  If so, use
+#                that path for mocks.
+CONFIG_MOCK_BASE = "openstack.config.loader"
+try:
+    from openstack.config import defaults   # noqa
+except ImportError:
+    # Fall back to os-client-config
+    CONFIG_MOCK_BASE = "os_client_config.config"
+
 
 class TestIntegShellCliV2(test_base.TestInteg):
 
@@ -389,8 +399,8 @@ class TestIntegShellCliPrecedenceOCC(test_base.TestInteg):
         test_shell.PUBLIC_1['public-clouds']['megadodo']['auth']['auth_url'] \
             = test_base.V3_AUTH_URL
 
-    @mock.patch("os_client_config.config.OpenStackConfig._load_vendor_file")
-    @mock.patch("os_client_config.config.OpenStackConfig._load_config_file")
+    @mock.patch(CONFIG_MOCK_BASE + ".OpenStackConfig._load_vendor_file")
+    @mock.patch(CONFIG_MOCK_BASE + ".OpenStackConfig._load_config_file")
     def test_shell_args_precedence_1(self, config_mock, vendor_mock):
         """Precedence run 1
 
@@ -405,6 +415,7 @@ class TestIntegShellCliPrecedenceOCC(test_base.TestInteg):
             return ('file.yaml', copy.deepcopy(test_shell.PUBLIC_1))
         vendor_mock.side_effect = vendor_mock_return
 
+        print("CONFIG_MOCK_BASE=%s" % CONFIG_MOCK_BASE)
         _shell = shell.OpenStackShell()
         _shell.run(
             "--os-password qaz configuration show".split(),
@@ -458,8 +469,8 @@ class TestIntegShellCliPrecedenceOCC(test_base.TestInteg):
         # +env, +cli, +occ
         # see test_shell_args_precedence_2()
 
-    @mock.patch("os_client_config.config.OpenStackConfig._load_vendor_file")
-    @mock.patch("os_client_config.config.OpenStackConfig._load_config_file")
+    @mock.patch(CONFIG_MOCK_BASE + ".OpenStackConfig._load_vendor_file")
+    @mock.patch(CONFIG_MOCK_BASE + ".OpenStackConfig._load_config_file")
     def test_shell_args_precedence_2(self, config_mock, vendor_mock):
         """Precedence run 2
 
@@ -474,6 +485,7 @@ class TestIntegShellCliPrecedenceOCC(test_base.TestInteg):
             return ('file.yaml', copy.deepcopy(test_shell.PUBLIC_1))
         vendor_mock.side_effect = vendor_mock_return
 
+        print("CONFIG_MOCK_BASE=%s" % CONFIG_MOCK_BASE)
         _shell = shell.OpenStackShell()
         _shell.run(
             "--os-username zarquon --os-password qaz "
